@@ -1,19 +1,22 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
+import os
 import re
 
+from lib.core.common import singleTimeWarnMessage
 from lib.core.common import zeroDepthSearch
+from lib.core.enums import DBMS
 from lib.core.enums import PRIORITY
 
 __priority__ = PRIORITY.HIGHEST
 
 def dependencies():
-    pass
+    singleTimeWarnMessage("tamper script '%s' is only meant to be run against %s" % (os.path.basename(__file__).split(".")[0], DBMS.MSSQL))
 
 def tamper(payload, **kwargs):
     """
@@ -64,7 +67,7 @@ def tamper(payload, **kwargs):
 
                 retVal = "%s%s%s)}%s" % (retVal[:start], "{fn CONCAT(" * count, ''.join(chars)[start:end].replace('\x01', ")},"), retVal[end:])
             else:
-                match = re.search(r"\((CHAR\(\d+.+CHAR\(\d+\))\)", retVal)
+                match = re.search(r"\((CHAR\(\d+.+\bCHAR\(\d+\))\)", retVal)
                 if match:
                     part = match.group(0)
                     indexes = set(zeroDepthSearch(match.group(1), '+'))
